Setsuen Chase - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Setsuen Chase

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/Setsuen%20Chase/Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/Setsuen%20Chase/Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.60 KiB | 04 Jan 2026 04:49:58
2 | Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.74 KiB | 04 Jan 2026 04:50:07

Nothing to show.

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/Setsuen%20Chase/Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_tv/Setsuen%20Chase/Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | Setsuen.Chase.Part.1.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.60 KiB | 04 Jan 2026 04:49:58
2 | Setsuen.Chase.Part.2.1080p.NHKP.WEB-DL.AAC2.0.H.264-MagicStar.srt | 140.74 KiB | 04 Jan 2026 04:50:07

Upload new files — Search MDL — Back to Index